@@ -7,16 +7,16 @@
 #define GPDATADIR "/usr/share/pari"
 #define SHELL_Q '\''
 
-#define PARIVERSION "GP/PARI CALCULATOR Version 2.13.4 (released)"
+#define PARIVERSION "GP/PARI CALCULATOR Version 2.15.0 (released)"
 #define PARIINFO "arm64 running linux (aarch64/GMP-%s kernel) 64-bit version"
-#define PARI_VERSION_CODE 134404
+#define PARI_VERSION_CODE 134912
 #define PARI_VERSION(a,b,c) (((a) << 16) + ((b) << 8) + (c))
 #define PARI_VERSION_SHIFT 8
 #define PARI_VCSVERSION ""
 #define PARI_MT_ENGINE "pthread"
 
 #define PARI_DOUBLE_FORMAT -
-#define GCC_VERSION "gcc version 11.2.0 (GCC)"
+#define GCC_VERSION "gcc version 12.1.0 (GCC)"
 #define ASMINLINE
 
 /*  Location of GNU gzip program (enables reading of .Z and .gz files). */
@@ -28,8 +28,10 @@
 
 #define READLINE "8.1"
 #define LONG_IS_64BIT
+#define HAS_NEON
 #define HAS_EXP2
 #define HAS_LOG2
+#define HAS_RINT
 #define HAS_ISATTY
 #define HAS_ALARM
 #define HAS_SYSTEM
